@@ -22,4 +22,14 @@ InverseFunctions.inverse(::typeof(logitexp)) = loglogistic
 InverseFunctions.inverse(::typeof(log1mlogistic)) = logit1mexp
 InverseFunctions.inverse(::typeof(logit1mexp)) = log1mlogistic
 
+InverseFunctions.inverse(::typeof(softplus)) = invsoftplus
+function InverseFunctions.inverse(f::Base.Fix2{typeof(softplus),<:Real})
+    Base.Fix2(invsoftplus, f.x)
+end
+
+InverseFunctions.inverse(::typeof(invsoftplus)) = softplus
+function InverseFunctions.inverse(f::Base.Fix2{typeof(invsoftplus),<:Real})
+    Base.Fix2(softplus, f.x)
+end
+
 end # module
