@@ -161,6 +161,16 @@ end
     end
 end
 
+@testset "softplus" begin
+    for T in (Int, Float64, Float32, Float16)
+        @test @inferred(softplus(T(2))) === log1pexp(T(2))
+        @test @inferred(softplus(T(2), 1)) isa float(T)
+        @test @inferred(softplus(T(2), 1)) ≈ softplus(T(2))
+        @test @inferred(softplus(T(2), 5)) ≈ softplus(5 * T(2)) / 5
+        @test @inferred(softplus(T(2), 10)) ≈ softplus(10 * T(2)) / 10
+    end
+end
+
 @testset "log1mexp" begin
     for T in (Float64, Float32, Float16)
         @test @inferred(log1mexp(-T(1))) isa T
@@ -186,6 +196,16 @@ end
     end
 end
 
+@testset "invsoftplus" begin
+    for T in (Int, Float64, Float32, Float16)
+        @test @inferred(invsoftplus(T(2))) === logexpm1(T(2))
+        @test @inferred(invsoftplus(T(2), 1)) isa float(T)
+        @test @inferred(invsoftplus(T(2), 1)) ≈ invsoftplus(T(2))
+        @test @inferred(invsoftplus(T(2), 5)) ≈ invsoftplus(5 * T(2)) / 5
+        @test @inferred(invsoftplus(T(2), 10)) ≈ invsoftplus(10 * T(2)) / 10
+    end
+end
+
 @testset "log1pmx" begin
     @test iszero(log1pmx(0.0))
     @test log1pmx(1.0) ≈ log(2.0) - 1.0
@@ -448,7 +468,7 @@ end
             @test cloglog(T(x)) ≈ cloglog_big(T(x))
             # Julia bug for Float32 and Float16 initially introduced in https://github.com/JuliaLang/julia/pull/37440
             # and fixed in https://github.com/JuliaLang/julia/pull/50989
-            if T === Float64 || VERSION < v"1.7.0-DEV.887" || VERSION >= v"1.11.0-DEV.310"
+            if T === Float64 || VERSION >= v"1.11.0-DEV.310"
                 @test cexpexp(T(x)) ≈ cexpexp_big(T(x))
             end
         end
