@@ -1,6 +1,11 @@
 @testset "inverse.jl" begin
     InverseFunctions.test_inverse(log1pexp, randn())
+    InverseFunctions.test_inverse(softplus, randn())
+    InverseFunctions.test_inverse(Base.Fix2(softplus, randexp()), randn())
+
     InverseFunctions.test_inverse(logexpm1, randexp())
+    InverseFunctions.test_inverse(invsoftplus, randexp())
+    InverseFunctions.test_inverse(Base.Fix2(invsoftplus, randexp()), randexp())
 
     InverseFunctions.test_inverse(log1mexp, -randexp())
 
